==> cognite_pygen-1.2.15.tar.gz: cognite_pygen-1.2.15/examples/omni/data_classes/__init__.py <==
from omni.data_classes._core import (
    DataRecord,
    DataRecordGraphQL,
    DataRecordWrite,
    DomainModel,
    DomainModelCore,
    DomainModelWrite,
    DomainModelList,
    DomainRelationWrite,
    GraphQLCore,
    GraphQLList,
    ResourcesWrite,
    ResourcesWriteResult,
    PageInfo,
    TimeSeriesGraphQL,
    FileMetadataGraphQL,
    SequenceColumnGraphQL,
    SequenceGraphQL,
)
from ._cdf_external_references import (
    CDFExternalReferences,
    CDFExternalReferencesFields,
    CDFExternalReferencesGraphQL,
    CDFExternalReferencesList,
    CDFExternalReferencesTextFields,
    CDFExternalReferencesWrite,
    CDFExternalReferencesWriteList,
)
from ._cdf_external_references_listed import (
    CDFExternalReferencesListed,
    CDFExternalReferencesListedFields,
    CDFExternalReferencesListedGraphQL,
    CDFExternalReferencesListedList,
    CDFExternalReferencesListedTextFields,
    CDFExternalReferencesListedWrite,
    CDFExternalReferencesListedWriteList,
)
from ._connection_edge_a import (
    ConnectionEdgeA,
    ConnectionEdgeAFields,
    ConnectionEdgeAGraphQL,
    ConnectionEdgeAList,
    ConnectionEdgeATextFields,
    ConnectionEdgeAWrite,
    ConnectionEdgeAWriteList,
)
from ._connection_item_a import (
    ConnectionItemA,
    ConnectionItemAFields,
    ConnectionItemAGraphQL,
    ConnectionItemAList,
    ConnectionItemATextFields,
    ConnectionItemAWrite,
    ConnectionItemAWriteList,
)
from ._connection_item_b import (
    ConnectionItemB,
    ConnectionItemBFields,
    ConnectionItemBGraphQL,
    ConnectionItemBList,
    ConnectionItemBTextFields,
    ConnectionItemBWrite,
    ConnectionItemBWriteList,
)
from ._connection_item_c_edge import (
    ConnectionItemCEdge,
    ConnectionItemCEdgeFields,
    ConnectionItemCEdgeGraphQL,
    ConnectionItemCEdgeList,
    ConnectionItemCEdgeTextFields,
)
from ._connection_item_c_node import (
    ConnectionItemCNode,
    ConnectionItemCNodeFields,
    ConnectionItemCNodeGraphQL,
    ConnectionItemCNodeList,
    ConnectionItemCNodeTextFields,
    ConnectionItemCNodeWrite,
    ConnectionItemCNodeWriteList,
)
from ._connection_item_d import (
    ConnectionItemD,
    ConnectionItemDFields,
    ConnectionItemDGraphQL,
    ConnectionItemDList,
    ConnectionItemDTextFields,
    ConnectionItemDWrite,
    ConnectionItemDWriteList,
)
from ._connection_item_e import (
    ConnectionItemE,
    ConnectionItemEFields,
    ConnectionItemEGraphQL,
    ConnectionItemEList,
    ConnectionItemETextFields,
    ConnectionItemEWrite,
    ConnectionItemEWriteList,
)
from ._connection_item_f import (
    ConnectionItemF,
    ConnectionItemFFields,
    ConnectionItemFGraphQL,
    ConnectionItemFList,
    ConnectionItemFTextFields,
    ConnectionItemFWrite,
    ConnectionItemFWriteList,
)
from ._connection_item_g import (
    ConnectionItemG,
    ConnectionItemGFields,
    ConnectionItemGGraphQL,
    ConnectionItemGList,
    ConnectionItemGTextFields,
    ConnectionItemGWrite,
    ConnectionItemGWriteList,
)
from ._dependent_on_non_writable import (
    DependentOnNonWritable,
    DependentOnNonWritableFields,
    DependentOnNonWritableGraphQL,
    DependentOnNonWritableList,
    DependentOnNonWritableTextFields,
    DependentOnNonWritableWrite,
    DependentOnNonWritableWriteList,
)
from ._empty import Empty, EmptyFields, EmptyGraphQL, EmptyList, EmptyTextFields, EmptyWrite, EmptyWriteList
from ._implementation_1 import (
    Implementation1,
    Implementation1Fields,
    Implementation1GraphQL,
    Implementation1List,
    Implementation1TextFields,
    Implementation1Write,
    Implementation1WriteList,
)
from ._implementation_1_non_writeable import (
    Implementation1NonWriteable,
    Implementation1NonWriteableFields,
    Implementation1NonWriteableGraphQL,
    Implementation1NonWriteableList,
    Implementation1NonWriteableTextFields,
)
from ._implementation_2 import (
    Implementation2,
    Implementation2Fields,
    Implementation2GraphQL,
    Implementation2List,
    Implementation2TextFields,
    Implementation2Write,
    Implementation2WriteList,
)
from ._main_interface import (
    MainInterface,
    MainInterfaceFields,
    MainInterfaceGraphQL,
    MainInterfaceList,
    MainInterfaceTextFields,
    MainInterfaceWrite,
    MainInterfaceWriteList,
)
from ._primitive_nullable import (
    PrimitiveNullable,
    PrimitiveNullableFields,
    PrimitiveNullableGraphQL,
    PrimitiveNullableList,
    PrimitiveNullableTextFields,
    PrimitiveNullableWrite,
    PrimitiveNullableWriteList,
)
from ._primitive_nullable_listed import (
    PrimitiveNullableListed,
    PrimitiveNullableListedFields,
    PrimitiveNullableListedGraphQL,
    PrimitiveNullableListedList,
    PrimitiveNullableListedTextFields,
    PrimitiveNullableListedWrite,
    PrimitiveNullableListedWriteList,
)
from ._primitive_required import (
    PrimitiveRequired,
    PrimitiveRequiredFields,
    PrimitiveRequiredGraphQL,
    PrimitiveRequiredList,
    PrimitiveRequiredTextFields,
    PrimitiveRequiredWrite,
    PrimitiveRequiredWriteList,
)
from ._primitive_required_listed import (
    PrimitiveRequiredListed,
    PrimitiveRequiredListedFields,
    PrimitiveRequiredListedGraphQL,
    PrimitiveRequiredListedList,
    PrimitiveRequiredListedTextFields,
    PrimitiveRequiredListedWrite,
    PrimitiveRequiredListedWriteList,
)
from ._primitive_with_defaults import (
    PrimitiveWithDefaults,
    PrimitiveWithDefaultsFields,
    PrimitiveWithDefaultsGraphQL,
    PrimitiveWithDefaultsList,
    PrimitiveWithDefaultsTextFields,
    PrimitiveWithDefaultsWrite,
    PrimitiveWithDefaultsWriteList,
)
from ._sub_interface import (
    SubInterface,
    SubInterfaceFields,
    SubInterfaceGraphQL,
    SubInterfaceList,
    SubInterfaceTextFields,
    SubInterfaceWrite,
    SubInterfaceWriteList,
)

CDFExternalReferences.model_rebuild()
CDFExternalReferencesGraphQL.model_rebuild()
CDFExternalReferencesWrite.model_rebuild()
CDFExternalReferencesListed.model_rebuild()
CDFExternalReferencesListedGraphQL.model_rebuild()
CDFExternalReferencesListedWrite.model_rebuild()
ConnectionItemA.model_rebuild()
ConnectionItemAGraphQL.model_rebuild()
ConnectionItemAWrite.model_rebuild()
ConnectionItemB.model_rebuild()
ConnectionItemBGraphQL.model_rebuild()
ConnectionItemBWrite.model_rebuild()
ConnectionItemCNode.model_rebuild()
ConnectionItemCNodeGraphQL.model_rebuild()
ConnectionItemCNodeWrite.model_rebuild()
ConnectionItemD.model_rebuild()
ConnectionItemDGraphQL.model_rebuild()
ConnectionItemDWrite.model_rebuild()
ConnectionItemE.model_rebuild()
ConnectionItemEGraphQL.model_rebuild()
ConnectionItemEWrite.model_rebuild()
ConnectionItemF.model_rebuild()
ConnectionItemFGraphQL.model_rebuild()
ConnectionItemFWrite.model_rebuild()
ConnectionItemG.model_rebuild()
ConnectionItemGGraphQL.model_rebuild()
ConnectionItemGWrite.model_rebuild()
DependentOnNonWritable.model_rebuild()
DependentOnNonWritableGraphQL.model_rebuild()
DependentOnNonWritableWrite.model_rebuild()
Implementation1NonWriteable.model_rebuild()
Implementation1NonWriteableGraphQL.model_rebuild()
ConnectionEdgeA.model_rebuild()
ConnectionEdgeAGraphQL.model_rebuild()
ConnectionEdgeAWrite.model_rebuild()
ConnectionItemCEdge.model_rebuild()
ConnectionItemCEdgeGraphQL.model_rebuild()


__all__ = [
    "DataRecord",
    "DataRecordGraphQL",
    "DataRecordWrite",
    "ResourcesWrite",
    "DomainModel",
    "DomainModelCore",
    "DomainModelWrite",
    "DomainModelList",
    "DomainRelationWrite",
    "GraphQLCore",
    "GraphQLList",
    "ResourcesWriteResult",
    "PageInfo",
    "TimeSeriesGraphQL",
    "FileMetadataGraphQL",
    "SequenceColumnGraphQL",
    "SequenceGraphQL",
    "CDFExternalReferences",
    "CDFExternalReferencesGraphQL",
    "CDFExternalReferencesWrite",
    "CDFExternalReferencesList",
    "CDFExternalReferencesWriteList",
    "CDFExternalReferencesFields",
    "CDFExternalReferencesTextFields",
    "CDFExternalReferencesListed",
    "CDFExternalReferencesListedGraphQL",
    "CDFExternalReferencesListedWrite",
    "CDFExternalReferencesListedList",
    "CDFExternalReferencesListedWriteList",
    "CDFExternalReferencesListedFields",
    "CDFExternalReferencesListedTextFields",
    "ConnectionEdgeA",
    "ConnectionEdgeAGraphQL",
    "ConnectionEdgeAWrite",
    "ConnectionEdgeAList",
    "ConnectionEdgeAWriteList",
    "ConnectionEdgeAFields",
    "ConnectionEdgeATextFields",
    "ConnectionItemA",
    "ConnectionItemAGraphQL",
    "ConnectionItemAWrite",
    "ConnectionItemAList",
    "ConnectionItemAWriteList",
    "ConnectionItemAFields",
    "ConnectionItemATextFields",
    "ConnectionItemB",
    "ConnectionItemBGraphQL",
    "ConnectionItemBWrite",
    "ConnectionItemBList",
    "ConnectionItemBWriteList",
    "ConnectionItemBFields",
    "ConnectionItemBTextFields",
    "ConnectionItemCEdge",
    "ConnectionItemCEdgeGraphQL",
    "ConnectionItemCEdgeList",
    "ConnectionItemCEdgeFields",
    "ConnectionItemCEdgeTextFields",
    "ConnectionItemCNode",
    "ConnectionItemCNodeGraphQL",
    "ConnectionItemCNodeWrite",
    "ConnectionItemCNodeList",
    "ConnectionItemCNodeWriteList",
    "ConnectionItemCNodeFields",
    "ConnectionItemCNodeTextFields",
    "ConnectionItemD",
    "ConnectionItemDGraphQL",
    "ConnectionItemDWrite",
    "ConnectionItemDList",
    "ConnectionItemDWriteList",
    "ConnectionItemDFields",
    "ConnectionItemDTextFields",
    "ConnectionItemE",
    "ConnectionItemEGraphQL",
    "ConnectionItemEWrite",
    "ConnectionItemEList",
    "ConnectionItemEWriteList",
    "ConnectionItemEFields",
    "ConnectionItemETextFields",
    "ConnectionItemF",
    "ConnectionItemFGraphQL",
    "ConnectionItemFWrite",
    "ConnectionItemFList",
    "ConnectionItemFWriteList",
    "ConnectionItemFFields",
    "ConnectionItemFTextFields",
    "ConnectionItemG",
    "ConnectionItemGGraphQL",
    "ConnectionItemGWrite",
    "ConnectionItemGList",
    "ConnectionItemGWriteList",
    "ConnectionItemGFields",
    "ConnectionItemGTextFields",
    "DependentOnNonWritable",
    "DependentOnNonWritableGraphQL",
    "DependentOnNonWritableWrite",
    "DependentOnNonWritableList",
    "DependentOnNonWritableWriteList",
    "DependentOnNonWritableFields",
    "DependentOnNonWritableTextFields",
    "Empty",
    "EmptyGraphQL",
    "EmptyWrite",
    "EmptyList",
    "EmptyWriteList",
    "EmptyFields",
    "EmptyTextFields",
    "Implementation1",
    "Implementation1GraphQL",
    "Implementation1Write",
    "Implementation1List",
    "Implementation1WriteList",
    "Implementation1Fields",
    "Implementation1TextFields",
    "Implementation1NonWriteable",
    "Implementation1NonWriteableGraphQL",
    "Implementation1NonWriteableList",
    "Implementation1NonWriteableFields",
    "Implementation1NonWriteableTextFields",
    "Implementation2",
    "Implementation2GraphQL",
    "Implementation2Write",
    "Implementation2List",
    "Implementation2WriteList",
    "Implementation2Fields",
    "Implementation2TextFields",
    "MainInterface",
    "MainInterfaceGraphQL",
    "MainInterfaceWrite",
    "MainInterfaceList",
    "MainInterfaceWriteList",
    "MainInterfaceFields",
    "MainInterfaceTextFields",
    "PrimitiveNullable",
    "PrimitiveNullableGraphQL",
    "PrimitiveNullableWrite",
    "PrimitiveNullableList",
    "PrimitiveNullableWriteList",
    "PrimitiveNullableFields",
    "PrimitiveNullableTextFields",
    "PrimitiveNullableListed",
    "PrimitiveNullableListedGraphQL",
    "PrimitiveNullableListedWrite",
    "PrimitiveNullableListedList",
    "PrimitiveNullableListedWriteList",
    "PrimitiveNullableListedFields",
    "PrimitiveNullableListedTextFields",
    "PrimitiveRequired",
    "PrimitiveRequiredGraphQL",
    "PrimitiveRequiredWrite",
    "PrimitiveRequiredList",
    "PrimitiveRequiredWriteList",
    "PrimitiveRequiredFields",
    "PrimitiveRequiredTextFields",
    "PrimitiveRequiredListed",
    "PrimitiveRequiredListedGraphQL",
    "PrimitiveRequiredListedWrite",
    "PrimitiveRequiredListedList",
    "PrimitiveRequiredListedWriteList",
    "PrimitiveRequiredListedFields",
    "PrimitiveRequiredListedTextFields",
    "PrimitiveWithDefaults",
    "PrimitiveWithDefaultsGraphQL",
    "PrimitiveWithDefaultsWrite",
    "PrimitiveWithDefaultsList",
    "PrimitiveWithDefaultsWriteList",
    "PrimitiveWithDefaultsFields",
    "PrimitiveWithDefaultsTextFields",
    "SubInterface",
    "SubInterfaceGraphQL",
    "SubInterfaceWrite",
    "SubInterfaceList",
    "SubInterfaceWriteList",
    "SubInterfaceFields",
    "SubInterfaceTextFields",
]

==> cognite_pygen-1.2.28.tar.gz: cognite_pygen-1.2.28/examples/omni/data_classes/__init__.py <==
from omni.data_classes._core import (
    DataRecord,
    DataRecordGraphQL,
    DataRecordWrite,
    DomainModel,
    DomainModelCore,
    DomainModelWrite,
    DomainModelList,
    DomainRelationWrite,
    GraphQLCore,
    GraphQLList,
    ResourcesWrite,
    ResourcesWriteResult,
    PageInfo,
    TimeSeriesGraphQL,
    FileMetadataGraphQL,
    SequenceColumnGraphQL,
    SequenceGraphQL,
)
from ._cdf_external_references import (
    CDFExternalReferences,
    CDFExternalReferencesFields,
    CDFExternalReferencesGraphQL,
    CDFExternalReferencesList,
    CDFExternalReferencesTextFields,
    CDFExternalReferencesWrite,
    CDFExternalReferencesWriteList,
)
from ._cdf_external_references_listed import (
    CDFExternalReferencesListed,
    CDFExternalReferencesListedFields,
    CDFExternalReferencesListedGraphQL,
    CDFExternalReferencesListedList,
    CDFExternalReferencesListedTextFields,
    CDFExternalReferencesListedWrite,
    CDFExternalReferencesListedWriteList,
)
from ._connection_edge_a import (
    ConnectionEdgeA,
    ConnectionEdgeAFields,
    ConnectionEdgeAGraphQL,
    ConnectionEdgeAList,
    ConnectionEdgeATextFields,
    ConnectionEdgeAWrite,
    ConnectionEdgeAWriteList,
)
from ._connection_item_a import (
    ConnectionItemA,
    ConnectionItemAFields,
    ConnectionItemAGraphQL,
    ConnectionItemAList,
    ConnectionItemATextFields,
    ConnectionItemAWrite,
    ConnectionItemAWriteList,
)
from ._connection_item_b import (
    ConnectionItemB,
    ConnectionItemBFields,
    ConnectionItemBGraphQL,
    ConnectionItemBList,
    ConnectionItemBTextFields,
    ConnectionItemBWrite,
    ConnectionItemBWriteList,
)
from ._connection_item_c_edge import (
    ConnectionItemCEdge,
    ConnectionItemCEdgeFields,
    ConnectionItemCEdgeGraphQL,
    ConnectionItemCEdgeList,
    ConnectionItemCEdgeTextFields,
)
from ._connection_item_c_node import (
    ConnectionItemCNode,
    ConnectionItemCNodeFields,
    ConnectionItemCNodeGraphQL,
    ConnectionItemCNodeList,
    ConnectionItemCNodeTextFields,
    ConnectionItemCNodeWrite,
    ConnectionItemCNodeWriteList,
)
from ._connection_item_d import (
    ConnectionItemD,
    ConnectionItemDFields,
    ConnectionItemDGraphQL,
    ConnectionItemDList,
    ConnectionItemDTextFields,
    ConnectionItemDWrite,
    ConnectionItemDWriteList,
)
from ._connection_item_e import (
    ConnectionItemE,
    ConnectionItemEFields,
    ConnectionItemEGraphQL,
    ConnectionItemEList,
    ConnectionItemETextFields,
    ConnectionItemEWrite,
    ConnectionItemEWriteList,
)
from ._connection_item_f import (
    ConnectionItemF,
    ConnectionItemFFields,
    ConnectionItemFGraphQL,
    ConnectionItemFList,
    ConnectionItemFTextFields,
    ConnectionItemFWrite,
    ConnectionItemFWriteList,
)
from ._connection_item_g import (
    ConnectionItemG,
    ConnectionItemGFields,
    ConnectionItemGGraphQL,
    ConnectionItemGList,
    ConnectionItemGTextFields,
    ConnectionItemGWrite,
    ConnectionItemGWriteList,
)
from ._connection_item_h import (
    ConnectionItemH,
    ConnectionItemHFields,
    ConnectionItemHGraphQL,
    ConnectionItemHList,
    ConnectionItemHTextFields,
    ConnectionItemHWrite,
    ConnectionItemHWriteList,
)
from ._dependent_on_non_writable import (
    DependentOnNonWritable,
    DependentOnNonWritableFields,
    DependentOnNonWritableGraphQL,
    DependentOnNonWritableList,
    DependentOnNonWritableTextFields,
    DependentOnNonWritableWrite,
    DependentOnNonWritableWriteList,
)
from ._empty import Empty, EmptyFields, EmptyGraphQL, EmptyList, EmptyTextFields, EmptyWrite, EmptyWriteList
from ._implementation_1 import (
    Implementation1,
    Implementation1Fields,
    Implementation1GraphQL,
    Implementation1List,
    Implementation1TextFields,
    Implementation1Write,
    Implementation1WriteList,
)
from ._implementation_1_non_writeable import (
    Implementation1NonWriteable,
    Implementation1NonWriteableFields,
    Implementation1NonWriteableGraphQL,
    Implementation1NonWriteableList,
    Implementation1NonWriteableTextFields,
)
from ._implementation_2 import (
    Implementation2,
    Implementation2Fields,
    Implementation2GraphQL,
    Implementation2List,
    Implementation2TextFields,
    Implementation2Write,
    Implementation2WriteList,
)
from ._main_interface import (
    MainInterface,
    MainInterfaceFields,
    MainInterfaceGraphQL,
    MainInterfaceList,
    MainInterfaceTextFields,
    MainInterfaceWrite,
    MainInterfaceWriteList,
)
from ._primitive_nullable import (
    PrimitiveNullable,
    PrimitiveNullableFields,
    PrimitiveNullableGraphQL,
    PrimitiveNullableList,
    PrimitiveNullableTextFields,
    PrimitiveNullableWrite,
    PrimitiveNullableWriteList,
)
from ._primitive_nullable_listed import (
    PrimitiveNullableListed,
    PrimitiveNullableListedFields,
    PrimitiveNullableListedGraphQL,
    PrimitiveNullableListedList,
    PrimitiveNullableListedTextFields,
    PrimitiveNullableListedWrite,
    PrimitiveNullableListedWriteList,
)
from ._primitive_required import (
    PrimitiveRequired,
    PrimitiveRequiredFields,
    PrimitiveRequiredGraphQL,
    PrimitiveRequiredList,
    PrimitiveRequiredTextFields,
    PrimitiveRequiredWrite,
    PrimitiveRequiredWriteList,
)
from ._primitive_required_listed import (
    PrimitiveRequiredListed,
    PrimitiveRequiredListedFields,
    PrimitiveRequiredListedGraphQL,
    PrimitiveRequiredListedList,
    PrimitiveRequiredListedTextFields,
    PrimitiveRequiredListedWrite,
    PrimitiveRequiredListedWriteList,
)
from ._primitive_with_defaults import (
    PrimitiveWithDefaults,
    PrimitiveWithDefaultsFields,
    PrimitiveWithDefaultsGraphQL,
    PrimitiveWithDefaultsList,
    PrimitiveWithDefaultsTextFields,
    PrimitiveWithDefaultsWrite,
    PrimitiveWithDefaultsWriteList,
)
from ._sub_interface import (
    SubInterface,
    SubInterfaceFields,
    SubInterfaceGraphQL,
    SubInterfaceList,
    SubInterfaceTextFields,
    SubInterfaceWrite,
    SubInterfaceWriteList,
)

CDFExternalReferences.model_rebuild()
CDFExternalReferencesGraphQL.model_rebuild()
CDFExternalReferencesWrite.model_rebuild()
CDFExternalReferencesListed.model_rebuild()
CDFExternalReferencesListedGraphQL.model_rebuild()
CDFExternalReferencesListedWrite.model_rebuild()
ConnectionItemA.model_rebuild()
ConnectionItemAGraphQL.model_rebuild()
ConnectionItemAWrite.model_rebuild()
ConnectionItemB.model_rebuild()
ConnectionItemBGraphQL.model_rebuild()
ConnectionItemBWrite.model_rebuild()
ConnectionItemCNode.model_rebuild()
ConnectionItemCNodeGraphQL.model_rebuild()
ConnectionItemCNodeWrite.model_rebuild()
ConnectionItemD.model_rebuild()
ConnectionItemDGraphQL.model_rebuild()
ConnectionItemDWrite.model_rebuild()
ConnectionItemE.model_rebuild()
ConnectionItemEGraphQL.model_rebuild()
ConnectionItemEWrite.model_rebuild()
ConnectionItemF.model_rebuild()
ConnectionItemFGraphQL.model_rebuild()
ConnectionItemFWrite.model_rebuild()
ConnectionItemG.model_rebuild()
ConnectionItemGGraphQL.model_rebuild()
ConnectionItemGWrite.model_rebuild()
ConnectionItemH.model_rebuild()
ConnectionItemHGraphQL.model_rebuild()
ConnectionItemHWrite.model_rebuild()
DependentOnNonWritable.model_rebuild()
DependentOnNonWritableGraphQL.model_rebuild()
DependentOnNonWritableWrite.model_rebuild()
Implementation1NonWriteable.model_rebuild()
Implementation1NonWriteableGraphQL.model_rebuild()
ConnectionEdgeA.model_rebuild()
ConnectionEdgeAGraphQL.model_rebuild()
ConnectionEdgeAWrite.model_rebuild()
ConnectionItemCEdge.model_rebuild()
ConnectionItemCEdgeGraphQL.model_rebuild()


__all__ = [
    "DataRecord",
    "DataRecordGraphQL",
    "DataRecordWrite",
    "ResourcesWrite",
    "DomainModel",
    "DomainModelCore",
    "DomainModelWrite",
    "DomainModelList",
    "DomainRelationWrite",
    "GraphQLCore",
    "GraphQLList",
    "ResourcesWriteResult",
    "PageInfo",
    "TimeSeriesGraphQL",
    "FileMetadataGraphQL",
    "SequenceColumnGraphQL",
    "SequenceGraphQL",
    "CDFExternalReferences",
    "CDFExternalReferencesGraphQL",
    "CDFExternalReferencesWrite",
    "CDFExternalReferencesList",
    "CDFExternalReferencesWriteList",
    "CDFExternalReferencesFields",
    "CDFExternalReferencesTextFields",
    "CDFExternalReferencesListed",
    "CDFExternalReferencesListedGraphQL",
    "CDFExternalReferencesListedWrite",
    "CDFExternalReferencesListedList",
    "CDFExternalReferencesListedWriteList",
    "CDFExternalReferencesListedFields",
    "CDFExternalReferencesListedTextFields",
    "ConnectionEdgeA",
    "ConnectionEdgeAGraphQL",
    "ConnectionEdgeAWrite",
    "ConnectionEdgeAList",
    "ConnectionEdgeAWriteList",
    "ConnectionEdgeAFields",
    "ConnectionEdgeATextFields",
    "ConnectionItemA",
    "ConnectionItemAGraphQL",
    "ConnectionItemAWrite",
    "ConnectionItemAList",
    "ConnectionItemAWriteList",
    "ConnectionItemAFields",
    "ConnectionItemATextFields",
    "ConnectionItemB",
    "ConnectionItemBGraphQL",
    "ConnectionItemBWrite",
    "ConnectionItemBList",
    "ConnectionItemBWriteList",
    "ConnectionItemBFields",
    "ConnectionItemBTextFields",
    "ConnectionItemCEdge",
    "ConnectionItemCEdgeGraphQL",
    "ConnectionItemCEdgeList",
    "ConnectionItemCEdgeFields",
    "ConnectionItemCEdgeTextFields",
    "ConnectionItemCNode",
    "ConnectionItemCNodeGraphQL",
    "ConnectionItemCNodeWrite",
    "ConnectionItemCNodeList",
    "ConnectionItemCNodeWriteList",
    "ConnectionItemCNodeFields",
    "ConnectionItemCNodeTextFields",
    "ConnectionItemD",
    "ConnectionItemDGraphQL",
    "ConnectionItemDWrite",
    "ConnectionItemDList",
    "ConnectionItemDWriteList",
    "ConnectionItemDFields",
    "ConnectionItemDTextFields",
    "ConnectionItemE",
    "ConnectionItemEGraphQL",
    "ConnectionItemEWrite",
    "ConnectionItemEList",
    "ConnectionItemEWriteList",
    "ConnectionItemEFields",
    "ConnectionItemETextFields",
    "ConnectionItemF",
    "ConnectionItemFGraphQL",
    "ConnectionItemFWrite",
    "ConnectionItemFList",
    "ConnectionItemFWriteList",
    "ConnectionItemFFields",
    "ConnectionItemFTextFields",
    "ConnectionItemG",
    "ConnectionItemGGraphQL",
    "ConnectionItemGWrite",
    "ConnectionItemGList",
    "ConnectionItemGWriteList",
    "ConnectionItemGFields",
    "ConnectionItemGTextFields",
    "ConnectionItemH",
    "ConnectionItemHGraphQL",
    "ConnectionItemHWrite",
    "ConnectionItemHList",
    "ConnectionItemHWriteList",
    "ConnectionItemHFields",
    "ConnectionItemHTextFields",
    "DependentOnNonWritable",
    "DependentOnNonWritableGraphQL",
    "DependentOnNonWritableWrite",
    "DependentOnNonWritableList",
    "DependentOnNonWritableWriteList",
    "DependentOnNonWritableFields",
    "DependentOnNonWritableTextFields",
    "Empty",
    "EmptyGraphQL",
    "EmptyWrite",
    "EmptyList",
    "EmptyWriteList",
    "EmptyFields",
    "EmptyTextFields",
    "Implementation1",
    "Implementation1GraphQL",
    "Implementation1Write",
    "Implementation1List",
    "Implementation1WriteList",
    "Implementation1Fields",
    "Implementation1TextFields",
    "Implementation1NonWriteable",
    "Implementation1NonWriteableGraphQL",
    "Implementation1NonWriteableList",
    "Implementation1NonWriteableFields",
    "Implementation1NonWriteableTextFields",
    "Implementation2",
    "Implementation2GraphQL",
    "Implementation2Write",
    "Implementation2List",
    "Implementation2WriteList",
    "Implementation2Fields",
    "Implementation2TextFields",
    "MainInterface",
    "MainInterfaceGraphQL",
    "MainInterfaceWrite",
    "MainInterfaceList",
    "MainInterfaceWriteList",
    "MainInterfaceFields",
    "MainInterfaceTextFields",
    "PrimitiveNullable",
    "PrimitiveNullableGraphQL",
    "PrimitiveNullableWrite",
    "PrimitiveNullableList",
    "PrimitiveNullableWriteList",
    "PrimitiveNullableFields",
    "PrimitiveNullableTextFields",
    "PrimitiveNullableListed",
    "PrimitiveNullableListedGraphQL",
    "PrimitiveNullableListedWrite",
    "PrimitiveNullableListedList",
    "PrimitiveNullableListedWriteList",
    "PrimitiveNullableListedFields",
    "PrimitiveNullableListedTextFields",
    "PrimitiveRequired",
    "PrimitiveRequiredGraphQL",
    "PrimitiveRequiredWrite",
    "PrimitiveRequiredList",
    "PrimitiveRequiredWriteList",
    "PrimitiveRequiredFields",
    "PrimitiveRequiredTextFields",
    "PrimitiveRequiredListed",
    "PrimitiveRequiredListedGraphQL",
    "PrimitiveRequiredListedWrite",
    "PrimitiveRequiredListedList",
    "PrimitiveRequiredListedWriteList",
    "PrimitiveRequiredListedFields",
    "PrimitiveRequiredListedTextFields",
    "PrimitiveWithDefaults",
    "PrimitiveWithDefaultsGraphQL",
    "PrimitiveWithDefaultsWrite",
    "PrimitiveWithDefaultsList",
    "PrimitiveWithDefaultsWriteList",
    "PrimitiveWithDefaultsFields",
    "PrimitiveWithDefaultsTextFields",
    "SubInterface",
    "SubInterfaceGraphQL",
    "SubInterfaceWrite",
    "SubInterfaceList",
    "SubInterfaceWriteList",
    "SubInterfaceFields",
    "SubInterfaceTextFields",
]
